%define major   6
%define libname %mklibname cryptopp %{major}
%define develname %mklibname -d cryptopp
%define staticname %mklibname -s -d cryptopp

Name:           libcryptopp
Version:        5.5.2
Release:        %mkrel 2
Epoch:          0
Summary:        Public domain C++ class library of cryptographic schemes
License:        Public Domain
Group:          System/Libraries
URL:            http://www.cryptopp.com/
Source0:        http://www.cryptopp.com/cryptopp551.zip
Patch0:         libcryptopp-autotools.patch
Patch1: libcryptopp-5.5.2-gcc4.3.patch
BuildRequires:  doxygen
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root

%description
Crypto++ Library is a public domain C++ class library of cryptographic 
schemes. Currently the library consists of the following features:

    * a class hierarchy with an API defined by abstract base classes 
    * AES(Rijndael) and AES candidates: RC6, MARS, Twofish, Serpent, 
      CAST-256
    * other symmetric block ciphers: IDEA, DES, Triple-DES (DES-EDE2 
      and DES-EDE3), DESX (DES-XEX3), RC2, RC5, Blowfish, TEA, XTEA, 
      SAFER, 3-WAY, GOST, SHARK, CAST-128, Square, Skipjack, Camellia, 
      SHACAL-2
    * generic block cipher modes: ECB, CBC, CBC ciphertext stealing 
      (CTS), CFB, OFB, counter mode (CTR)
    * stream ciphers: Salsa20, Panama, ARC4, SEAL, WAKE, WAKE-OFB, 
      BlumBlumShub
    * public-key cryptography: RSA, DSA, ElGamal, Nyberg-Rueppel (NR),
      Rabin, Rabin-Williams (RW), LUC, LUCELG, DLIES (variants of 
      DHAES), ESIGN
    * padding schemes for public-key systems: PKCS#1 v2.0, OAEP, PSS, 
      PSSR, IEEE P1363 EMSA2 and EMSA5
    * key agreement schemes: Diffie-Hellman (DH), Unified
      Diffie-Hellman (DH2), Menezes-Qu-Vanstone (MQV), LUCDIF, XTR-DH
    * elliptic curve cryptography: ECDSA, ECNR, ECIES, ECDH, ECMQV
    * one-way hash functions: SHA-1, MD2, MD4, MD5, HAVAL, RIPEMD-128, 
      RIPEMD-256, RIPEMD-160, RIPEMD-320, Tiger, SHA-2 (SHA-224, 
      SHA-256, SHA-384, and SHA-512), Panama, WHIRLPOOL
    * message authentication codes: MD5-MAC, HMAC, XOR-MAC, CBC-MAC, 
      DMAC, Two-Track-MAC
    * cipher constructions based on hash functions: Luby-Rackoff, MDC
    * pseudo random number generators (PRNG): ANSI X9.17 appendix C, 
      PGP's RandPool
    * password based key derivation functions: PBKDF1 and PBKDF2 from 
      PKCS #5
    * Shamir's secret sharing scheme and Rabin's information dispersal 
      algorithm (IDA)
    * DEFLATE (RFC 1951) compression/decompression with gzip (RFC 
      1952) and zlib (RFC 1950) format support
    * fast multi-precision integer (bignum) and polynomial operations, 
      with SSE2 optimizations for Pentium 4 processors, and support for 
      64-bit CPUs
    * finite field arithmetics, including GF(p) and GF(2^n)
    * prime number generation and verification
    * various miscellaneous modules such as base 64 coding and 32-bit 
      CRC
    * class wrappers for these operating system features (optional):
          o high resolution timers on Windows, Unix, and MacOS
          o Berkeley and Windows style sockets
          o Windows named pipes
          o /dev/random, /dev/urandom, /dev/srandom
          o Microsoft's CryptGenRandom on Windows 
    * A high level interface for most of the above, using a 
      filter/pipeline metaphor
    * benchmarks and validation testing
    * FIPS 140-2 Validated 

Because one purpose of the project is to act as a repository of public 
domain (not copyrighted) cryptographic source code, the code in 
Crypto++ was either written specifically for this project by its 
contributors and placed in the public domain, or derived from other 
sources that are public domain (again with the exception of mars.cpp).

%package -n %{libname}
Group:          System/Libraries
Summary:        Base shared library part of %{name}
Provides:       %{name} = %{epoch}:%{version}-%{release}

%description -n %libname
Crypto++ Library is a free C++ class library of cryptographic schemes.

This package contains the library needed to run programs dynamically
linked with %{name}.

%package -n %develname
Summary:        Header files and development documentation for %{name}
Group:          Development/C++
Requires:       %{libname} = %{epoch}:%{version}-%{release}
Provides:       %{name}-devel = %{epoch}:%{version}-%{release}
Provides:       %{_lib}cryptopp-devel = %{epoch}:%{version}-%{release}
Provides:       cryptopp-devel = %{epoch}:%{version}-%{release}
Obsoletes: %mklibname -d cryptopp 6

%description -n %develname
Crypto++ Library is a free C++ class library of cryptographic schemes.

This package contains the header files and development documentation
for %{name}.

%package -n %staticname
Summary:        Static libraries for programs which will use %{name}
Group:          Development/C++
Requires:       %develname = %{epoch}:%{version}-%{release}
Provides:       %{name}-static-devel = %{epoch}:%{version}-%{release}
Provides:       cryptopp-static-devel = %{epoch}:%{version}-%{release}
Obsoletes: %mklibname -s -d cryptopp 6

%description -n %staticname
Crypto++ Library is a free C++ class library of cryptographic schemes.

This package contains the static library for %{name}.

%package doc
Summary:        Documentation for %{name}
Group:          Development/C++
Provides:       cryptopp-doc = %{epoch}:%{version}-%{release}

%description doc
Crypto++ Library is a free C++ class library of cryptographic schemes.

This package contains documentation for %{name}.

%package progs
Summary:        Programs for manipulating %{name} routines
Group:          Development/Other
Provides:       cryptopp-progs = %{epoch}:%{version}-%{release}

%description progs
Crypto++ Library is a free C++ class library of cryptographic schemes.

This package contains programs for manipulating %{name} routines.

%prep
%setup -q -c
%{__rm} -f GNUmakefile
%patch0 -p1
%patch1 -p1
%{_bindir}/autoreconf --verbose --force --install
%{configure2_5x}

%build
%{make}
%{_bindir}/doxygen

%install
%{__rm} -rf %{buildroot}
%{makeinstall}

%{__perl} -pi -e 's/\r$//g' License.txt Readme.txt

%check
%{__mkdir_p} tmp
%{__cp} -a *.dat TestVectors/* tmp
(cd tmp && ../cryptest v > cryptest.log 2>&1 && \
test ! -z "`%{__grep} -q '^FAILED' cryptest.log`" || exit 1)
%{__rm} -r tmp

%clean
%{__rm} -rf %{buildroot}

%if %mdkversion < 200900
%post -n %{libname} -p /sbin/ldconfig
%endif

%if %mdkversion < 200900
%postun -n %{libname} -p /sbin/ldconfig
%endif

%files -n %{libname}
%defattr(0644,root,root,0755)
%doc License.txt Readme.txt
%defattr(-,root,root,0755)
%{_libdir}/*.so.%{major}*

%files -n %develname
%defattr(0644,root,root,0755)
%{_includedir}/cryptopp
%defattr(-,root,root,0755)
%{_libdir}/*.so
%{_libdir}/*.la

%files -n %staticname
%defattr(-,root,root,0755)
%{_libdir}/*.a

%files doc
%defattr(0644,root,root,0755)
%doc doc/html/*

%files progs
%defattr(0644,root,root,0755)
%attr(0755,root,root) %{_bindir}/cryptest
%{_datadir}/cryptopp


%changelog
* Fri Aug 08 2008 Thierry Vignaud <tvignaud@mandriva.com> 0:5.5.2-2mdv2009.0
+ Revision: 267807
- rebuild early 2009.0 package (before pixel changes)

* Thu Jun 12 2008 Götz Waschk <waschk@mandriva.org> 0:5.5.2-1mdv2009.0
+ Revision: 218494
- new version
- patch for gcc 4.3
- new devel name
- fix obsoletes

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tvignaud@mandriva.com>
    - kill re-definition of %%buildroot on Pixel's request

* Mon Sep 17 2007 David Walluck <walluck@mandriva.org> 0:5.5.1-2mdv2008.0
+ Revision: 88832
- add some cryptopp Provides

* Sat Jun 02 2007 David Walluck <walluck@mandriva.org> 0:5.5.1-1mdv2008.0
+ Revision: 34430
- 5.5.1
- change so version to 6:0:0 to match Debian

* Sun May 06 2007 David Walluck <walluck@mandriva.org> 0:5.5-1mdv2008.0
+ Revision: 23769
- 5.5


* Mon Jan 29 2007 David Walluck <walluck@mandriva.org> 5.4-1mdv2007.0
+ Revision: 114844
- 5.4
- Import libcryptopp

* Fri May 19 2006 David Walluck <walluck@mandriva.org> 0:5.3-0.20060518.1mdk
- CVS (20060518)
- enable standard CXXFLAGS
- disable P4 and SSE2 optimizations on x86-64

* Tue Aug 16 2005 David Walluck <walluck@mandriva.org> 0:5.3-0.20050714.1mdk
- 5.3 (CVS 20050714)
- patch (from cryptopp mailing list) to compile with GCC4
- BuildRequires: doxygen

* Sun Nov 07 2004 David Walluck <walluck@mandrake.org> 5.2.1-2mdk
- add doc package containing API documentation
- disable all optimizations to prevent miscompilation
- [DIRM]
- no need to add the same docs to every package

* Sun Jul 25 2004 Pierre-Michel Theveny <pmth@free.fr> 5.2.1-1mdk
- Updated to 5.2.1
- Change compile options to pass cryptest on 5.2.1

* Thu Jul 15 2004 Pierre-Michel Theveny <pmth@free.fr> 5.2-1mdk
- Updated to 5.2

* Mon Mar 01 2004 Lenny Cartier <lenny@mandrakesoft.com> 5.1-1mdk
- from Pierre-Michel Theveny <pmth@free.fr> :
	- Fixed problem with broken library (do not use -O2 !)
	- Added patch for GNU autotools and libtool support
	- Added package progs

* Thu Feb 19 2004 Pierre-Michel Theveny <pmth@free.fr> 5.1-1mdk
- Ported to Mandrake 9.2
- Added shared library

* Wed Feb 18 2004 Ariano Bertacca <ariano@hirnriss.net> 5.1-1
- released libcryptopp-5.1-1

